@@ -5,8 +5,9 @@ from django.db.models import TextField
 from djangocodemirror.widgets import CodeMirrorWidget
 
 class SnippetAdmin(admin.ModelAdmin):
-    list_display = ('name', )
-    search_fields = ['name']
+    list_display = ('slug', 'name')
+    search_fields = ['slug', 'name']
+    prepopulated_fields = {"slug": ("name",)}
     formfield_overrides = {
         TextField: {'widget': CodeMirrorWidget(config_name='cms_snippet')},
     }
